@@ -11,7 +11,6 @@
 #include "pos-config.h"
 
 #include "phosh-osk-enums.h"
-#include "pos-debug-widget.h"
 #include "pos-emoji-picker.h"
 #include "pos-input-method.h"
 #include "pos-completer.h"
@@ -110,9 +109,6 @@ struct _PosInputSurface {
   PosShortcutsBar         *shortcuts_bar;
   PhoshOskFeatures         osk_features;
 
-  /* The debug surface */
-  PosDebugWidget          *debug_widget;
-
   /* TODO: this should be an interface for different keyboard drivers */
   PosVkDriver             *keyboard_driver;
 
@@ -928,7 +924,6 @@ pos_input_surface_set_property (GObject      *object,
   switch (property_id) {
   case PROP_INPUT_METHOD:
     self->input_method = g_value_dup_object (value);
-    pos_debug_widget_set_input_method (self->debug_widget, self->input_method);
     break;
   case PROP_COMPLETER_MANAGER:
     pos_input_surface_set_completer_manager (self, g_value_get_object (value));
@@ -1185,6 +1180,7 @@ pos_input_surface_finalize (GObject *object)
 
   g_clear_handle_id (&self->animation.id, g_source_remove);
 
+  g_clear_object (&self->keyboard_driver);
   g_clear_object (&self->input_method);
   g_clear_object (&self->a11y_settings);
   g_clear_object (&self->input_settings);
@@ -1356,7 +1352,6 @@ pos_input_surface_class_init (PosInputSurfaceClass *klass)
   pos_init ();
 
   g_type_ensure (POS_TYPE_COMPLETION_BAR);
-  g_type_ensure (POS_TYPE_DEBUG_WIDGET);
   g_type_ensure (POS_TYPE_EMOJI_PICKER);
   g_type_ensure (POS_TYPE_OSK_WIDGET);
   g_type_ensure (POS_TYPE_SHORTCUTS_BAR);
@@ -1364,7 +1359,6 @@ pos_input_surface_class_init (PosInputSurfaceClass *klass)
   gtk_widget_class_set_template_from_resource (widget_class,
                                                "/sm/puri/phosh/osk-stub/ui/input-surface.ui");
   gtk_widget_class_bind_template_child (widget_class, PosInputSurface, completion_bar);
-  gtk_widget_class_bind_template_child (widget_class, PosInputSurface, debug_widget);
   gtk_widget_class_bind_template_child (widget_class, PosInputSurface, deck);
   gtk_widget_class_bind_template_child (widget_class, PosInputSurface, emoji_picker);
   gtk_widget_class_bind_template_child (widget_class, PosInputSurface, osk_terminal);
@@ -1589,6 +1583,12 @@ insert_ibus_layout (PosInputSurface *self, const char *type, const char *id)
     g_warning ("ibus layout '%s' not parsable - ignoring", id);
     return NULL;
   }
+
+  if (g_strv_length (parts) < 2) {
+    g_warning ("ibus layout '%s' has no language - ignoring", id);
+    return NULL;
+  }
+
   engine_name = parts[0];
   lang = parts[1];
 
